# ✈飞机大战
---

### 安装说明
### 运行：
```bash
pip install pygame
python main.py
```
### 版本：Python3
###使用说明
1. 移动： WASD四个按键
2. 射击： 鼠标左键射一个子弹，鼠标右键射三个子弹，可长按鼠标。可连射的子弹数有控制，可通过吃物品增加。
3. 召唤盟友：鼠标中键，减掉3个血


### 待办
4. 添加注释
5. 分离base模块
6. 生成文档
8. 优化效率



